
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef rmp440_MSG_LIB_H
#define rmp440_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "rmp440Type.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  RMP440_MBOX_NAME                  genomInstanceName("rmp440")

#define  RMP440_MAX_RQST_SIZE              128

#define  RMP440_MBOX_RQST_SIZE       \
 (BUF_SIZE(RMP440_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  RMP440_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  RMP440_MAX_REPLY_SIZE             56

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  RMP440_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(RMP440_MAX_REPLY_SIZE) \
   + BUF_SIZE(RMP440_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define RMP440_INIT_RQST 0
#define RMP440_SETCMDPARAM_RQST 1
#define RMP440_SETKINEMATICSPARAM_RQST 2
#define RMP440_GETDYNAMICSPARAM_RQST 3
#define RMP440_SETVARPARAM_RQST 4
#define RMP440_STOP_RQST 5
#define RMP440_JOYSTICKON_RQST 6
#define RMP440_TRACK_RQST 7
#define RMP440_SETPOM_RQST 8
#define RMP440_SETPOS_RQST 9
#define RMP440_GYRO_RQST 10
#define RMP440_GETGYRO_RQST 11
#define RMP440_SETODOMETRYMETHOD_RQST 12
#define RMP440_LOG_RQST 13
#define RMP440_STOPLOG_RQST 14
#define RMP440_LOGINTERNALDATA_RQST 15
#define RMP440_STOPINTERNALDATALOG_RQST 16
#define RMP440_GOTO_RQST 17
#define RMP440_ABORT_RQST 18


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS rmp440ClientInit (CLIENT_ID *pClientId);

STATUS rmp440ClientEnd (CLIENT_ID clientId);

int rmp440AbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int rmp440AbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int rmp440AbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS rmp440InitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING32 *(in_device),
					 int replyTimeOut);

extern int rmp440InitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440InitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING32 *(in_device), 
					
					int *activity, int *bilan);

extern int rmp440InitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING32 *(in_device), 
					
					int *activity,
					int *bilan);




extern STATUS rmp440SetCmdParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_CMD_PARAM *(in_cmd),
					 int replyTimeOut);

int rmp440SetCmdParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440SetCmdParamRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_CMD_PARAM *(in_cmd), 
				 
				 int *bilan);




extern STATUS rmp440SetKinematicsParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 RMP440_KINEMATICS_STR *(in_kinematics),
					 int replyTimeOut);

int rmp440SetKinematicsParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440SetKinematicsParamRqstAndRcv (CLIENT_ID clientId, 
				 RMP440_KINEMATICS_STR *(in_kinematics), 
				 
				 int *bilan);




extern STATUS rmp440GetDynamicsParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int rmp440GetDynamicsParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       RMP440_DYNAMIC_STR *(out_dynamics),
			       int *bilan);

int rmp440GetDynamicsParamRqstAndRcv (CLIENT_ID clientId, 
				  
				 RMP440_DYNAMIC_STR *(out_dynamics),
				 int *bilan);




extern STATUS rmp440SetVarParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 RMP440_VAR_PARAMS *(in_varParams),
					 int replyTimeOut);

int rmp440SetVarParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440SetVarParamRqstAndRcv (CLIENT_ID clientId, 
				 RMP440_VAR_PARAMS *(in_varParams), 
				 
				 int *bilan);




extern STATUS rmp440StopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int rmp440StopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440StopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS rmp440JoystickOnRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int rmp440JoystickOnReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440JoystickOnRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int rmp440JoystickOnRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS rmp440TrackRqstSend (CLIENT_ID clientId, int *pRqstId,
					 RMP440_TRACK_PARAMS *(in_trackParams),
					 int replyTimeOut);

extern int rmp440TrackReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440TrackRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					RMP440_TRACK_PARAMS *(in_trackParams), 
					
					int *activity, int *bilan);

extern int rmp440TrackRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					RMP440_TRACK_PARAMS *(in_trackParams), 
					
					int *activity,
					int *bilan);




extern STATUS rmp440SetPomRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GENPOS_POSTER_NAME *(in_mePosterName),
					 int replyTimeOut);

extern int rmp440SetPomReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440SetPomRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GENPOS_POSTER_NAME *(in_mePosterName), 
					
					int *activity, int *bilan);

extern int rmp440SetPomRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GENPOS_POSTER_NAME *(in_mePosterName), 
					
					int *activity,
					int *bilan);




extern STATUS rmp440SetPosRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 RMP440_CART_3DCONFIG *(in_setPosStr),
					 int replyTimeOut);

int rmp440SetPosReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440SetPosRqstAndRcv (CLIENT_ID clientId, 
				 RMP440_CART_3DCONFIG *(in_setPosStr), 
				 
				 int *bilan);




extern STATUS rmp440GyroRqstSend (CLIENT_ID clientId, int *pRqstId,
					 RMP440_GYRO_PARAMS *(in_params),
					 int replyTimeOut);

extern int rmp440GyroReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440GyroRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					RMP440_GYRO_PARAMS *(in_params), 
					
					int *activity, int *bilan);

extern int rmp440GyroRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					RMP440_GYRO_PARAMS *(in_params), 
					
					int *activity,
					int *bilan);




extern STATUS rmp440GetGyroRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int rmp440GetGyroReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       RMP440_GYRO_PARAMS *(out_params),
			       int *bilan);

int rmp440GetGyroRqstAndRcv (CLIENT_ID clientId, 
				  
				 RMP440_GYRO_PARAMS *(out_params),
				 int *bilan);




extern STATUS rmp440SetOdometryMethodRqstSend (CLIENT_ID clientId, int *pRqstId,
					 RMP440_ODOMETRY_METHOD *(in_odometryCommand),
					 int replyTimeOut);

extern int rmp440SetOdometryMethodReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440SetOdometryMethodRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					RMP440_ODOMETRY_METHOD *(in_odometryCommand), 
					
					int *activity, int *bilan);

extern int rmp440SetOdometryMethodRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					RMP440_ODOMETRY_METHOD *(in_odometryCommand), 
					
					int *activity,
					int *bilan);




extern STATUS rmp440LogRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_fileName),
					 int replyTimeOut);

extern int rmp440LogReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440LogRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity, int *bilan);

extern int rmp440LogRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity,
					int *bilan);




extern STATUS rmp440StopLogRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int rmp440StopLogReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440StopLogRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS rmp440LogInternalDataRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_fileName),
					 int replyTimeOut);

extern int rmp440LogInternalDataReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int rmp440LogInternalDataRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity, int *bilan);

extern int rmp440LogInternalDataRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity,
					int *bilan);




extern STATUS rmp440StopInternalDataLogRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int rmp440StopInternalDataLogReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440StopInternalDataLogRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS rmp440GotoRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_REF *(in_ref),
					 int replyTimeOut);

int rmp440GotoReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int rmp440GotoRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_REF *(in_ref), 
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* rmp440_MSG_LIB_H */

